@@ -161,7 +161,7 @@ spline.correlog2D <- function(x, y, z, w = NULL, df = NULL, type = "boot",
       
       for (i in 1:resamp) {
         whn <- pretty(c(1, resamp), n = 10)
-        if (quiet & any(i == whn)) {
+        if (!quiet & any(i == whn)) {
           cat(i, " of ", resamp, "(direction", d, "of ", length(ang), ")\r")
           flush.console()
         }
